<?php
/**
 * @file
 * This is a base class that makes it easier to test content providers features,
 * which matches the description of any feature that defines a content type.
 */

/**
 * Test class that can be used to make it easier to test features that provides
 * content types.
 */
class NSContentProviderTestCase extends NodeStreamWebTestCase {

  /**
   * Check that a a particular references dialog view is attached to an instance.
   * @param $view_name The name of the view that should be attached.
   * @param $display_name The name of the display that should be attached.
   * @param $field_instance The instance the view is attached to.
   */
  public function assertReferencesDialogView($view_name, $display_name, array $field_instance, $message = NULL) {
    if (!isset($message)) {
      $message = t('The references dialog search view is attached to %field_name in %bundle on %entity_type',
        array('%field_name' => $field_instance['field_name'], '%bundle' => $field_instance['bundle'], '%entity_type' => $field_instance['entity_type']));
    }
    $view = views_get_view($view_name);
    $this->assertTrue(isset($view), t('The view %view_name exists', array('%view_name', $view_name)));
    $this->assertTrue(isset($view->display[$display_name]), t('The display %display_name exists', array('%display_name' => $display_name)));
    $display = $view->display[$display_name];
    $attachable_name = $field_instance['entity_type'] . ':' . $field_instance['field_name'] . ':' . $field_instance['bundle'];
    $this->assertTrue(in_array($attachable_name, $display->display_options['attach']), $message);
  }

  /**
   * Asserts that a set of fields exists.
   * @param array $fields an array with the names of the fields that should be checked.
   */
  function assertFieldsExisting(array $fields) {
    $existing_fields = field_info_fields();
    foreach ($fields as $field) {
      $this->assertTrue(isset($existing_fields[$field]), t('The field %field exists.', array('%field' => $field)));
    }
  }

  /**
   * Assert that a a particular content type exists.
   * @param $name
   *   The name of the content type to check.
   */
  function assertContentType($name, $message = NULL) {
    if (!isset($message)) {
      $message = t('The content type %type exists', array('%type' => $name));
    }
    $types = node_type_get_types();
    $this->assertTrue(isset($types[$name]), t('The article content type exists'), $message);
  }

  /**
   * Get a nice lorem ipsum string.
   * @return string
   *   A string of lorem ipsum text.
   */
  protected function loremIpsum() {
    return 'Cupcake ipsum dolor sit. Amet icing bear claw gingerbread cake danish. Fruitcake cookie bear claw danish. Pie topping gummi bears candy biscuit gingerbread carrot cake topping. Jelly-o pastry lemon drops. Marshmallow jelly-o chocolate bar sugar plum bonbon halvah fruitcake. Liquorice dragée croissant chocolate tart tiramisu lollipop. Soufflé pudding liquorice lemon drops. Brownie gummi bears tart oat cake bonbon tiramisu. Faworki toffee liquorice jelly-o. Marzipan tiramisu cake jelly-o cheesecake. Cake pastry brownie powder chupa chups. Pie dessert cake pie ice cream sugar plum marzipan icing.';
  }
  /**
   * Create a content editor for a set of content types.
   * @param array $content_types
   *   An array of content types to add permissions for.
   * @return A created user.
   */
  protected function createContentEditor($content_types) {
    if (!is_array($content_types)) {
      $content_types = array($content_types);
    }
    $permissions = array(
      'access content',
      'view own unpublished content',
    );
    foreach ($content_types as $content_type) {
      $permissions = array_merge($permissions, array(
        "create $content_type content",
        "edit own $content_type content",
        "delete own $content_type content",
      ));
    }
    return $this->drupalCreateUser($permissions);
  }

  protected function createTestFile($type = 'image') {
    $test_file = current($this->drupalGetTestFiles($type));
    file_save($test_file);
    return $test_file;
  }

  public function assertDeleteForm($editor, $nid) {
    if (is_object($nid)) {
      $nid = $nid->nid;
    }
    $this->drupalLogin($editor);
    $this->drupalGet('node/' . $nid . '/delete');
    $this->drupalPost(NULL, array(), t('Delete'));
    $deleted_node = node_load($nid, NULL, TRUE);
    $this->assertFalse($deleted_node, t('The node does not exist, it has been deleted.'));
  }
}